OC.L10N.register(
    "files",
    {
    "Added to favorites" : "お気に入りに追加",
    "Removed from favorites" : "お気に入りから削除",
    "You added {file} to your favorites" : "{file} をお気に入りに追加しました",
    "You removed {file} from your favorites" : "{file} をお気に入りから削除しました",
    "Favorites" : "お気に入り",
    "File changes" : "ファイル更新",
    "Created by {user}" : "{user} が作成しました",
    "Changed by {user}" : "{user} が更新しました",
    "Deleted by {user}" : "{user} が削除しました",
    "Restored by {user}" : "{user} が復元しました",
    "Renamed by {user}" : "{user} が作成しました",
    "Moved by {user}" : "{user} が移動しました",
    "\"remote account\"" : "\"リモートアカウント\"",
    "You created {file}" : "{file} を作成しました",
    "You created an encrypted file in {file}" : "{file} で暗号化ファイルを作成しました",
    "{user} created {file}" : "{user} が {file} を作成しました",
    "{user} created an encrypted file in {file}" : "{user}が{file}に暗号化ファイルを作成しました",
    "{file} was created in a public folder" : "公開フォルダーに {file} が作成されました",
    "You changed {file}" : "{file} を更新しました",
    "You changed an encrypted file in {file}" : "{file}で暗号化されたファイルを変更しました。",
    "{user} changed {file}" : "{user} が {file} を更新しました",
    "{user} changed an encrypted file in {file}" : "{user}が{file}に暗号化ファイルを変更しました",
    "You deleted {file}" : "{file} を削除しました",
    "You deleted an encrypted file in {file}" : "{file}で暗号化されたファイルを削除しました。",
    "{user} deleted {file}" : "{user} が {file} を削除しました",
    "{user} deleted an encrypted file in {file}" : "{user}が{file}で暗号化されたファイルを削除しました",
    "You restored {file}" : "{file} を復元しました",
    "{user} restored {file}" : "{user} が {file} を復元しました",
    "You renamed {oldfile} (hidden) to {newfile} (hidden)" : "{oldfile}(非表示) の名前を {newfile}(非表示) に変更しました",
    "You renamed {oldfile} (hidden) to {newfile}" : "{oldfile} (非表示)の名前を{newfile}に変更しました",
    "You renamed {oldfile} to {newfile} (hidden)" : "{oldfile}の名前を{newfile}(非表示)に変更しました",
    "You renamed {oldfile} to {newfile}" : "{oldfile} を {newfile} に変更しました",
    "{user} renamed {oldfile} (hidden) to {newfile} (hidden)" : "{user} は {oldfile}(非表示) の名前を {newfile}(非表示)  に変更しました",
    "{user} renamed {oldfile} (hidden) to {newfile}" : "{user} は {oldfile} (非表示) の名前を {newfile} に変更しました",
    "{user} renamed {oldfile} to {newfile} (hidden)" : "{user}は{oldfile}を{newfile} (非表示)に名前変更しました",
    "{user} renamed {oldfile} to {newfile}" : "{user} が {oldfile} を{newfile} に変更しました",
    "You moved {oldfile} to {newfile}" : "{oldfile} を {newfile} に移動しました",
    "{user} moved {oldfile} to {newfile}" : "{user} が {oldfile} を {newfile} に移動しました",
    "A file has been added to or removed from your <strong>favorites</strong>" : "<strong>お気に入り</strong>にファイルが追加または削除されたとき",
    "Files" : "ファイル",
    "A file or folder has been <strong>changed</strong>" : "ファイルまたはフォルダーが<strong>変更</strong>されたとき",
    "A favorite file or folder has been <strong>changed</strong>" : "お気に入りのファイルまたはフォルダーが <strong>変更</strong>されたとき",
    "Failed to authorize" : "認証に失敗しました",
    "Invalid folder path" : "無効なフォルダーパス",
    "Folder not found" : "フォルダーが見つかりません",
    "The file cannot be found" : "ファイルが見つかりません",
    "The destination path does not exist: %1$s" : "宛先のパスが存在しません: %1$s",
    "You do not have permission to create a file at the specified location" : "指定された場所にファイルを作成する権限がありません",
    "The file could not be converted." : "ファイルを変換できませんでした。",
    "Could not get relative path to converted file" : "変換後のファイルへの相対パスを取得できませんでした",
    "Limit must be a positive integer." : "制限は正の整数である必要があります。",
    "The replacement character may only be a single character." : "置換文字は1文字のみです。",
    "Filename sanitization already started." : "ファイル名のサニタイズは既に開始されています。",
    "No filename sanitization in progress." : "進行中のファイル名サニタイズ処理はありません。",
    "Favorite files" : "お気に入りファイル",
    "No favorites" : "お気に入りなし",
    "More favorites" : "その他のお気に入り",
    "Accept" : "承諾",
    "Reject" : "拒否",
    "Incoming ownership transfer from {user}" : "{user} からの所有権転送を受信",
    "Do you want to accept {path}?\n\nNote: The transfer process after accepting may take up to 1 hour." : "{path} を承諾しますか？\n\n注意：承諾後の転送処理には最大 1 時間かかる場合があります。",
    "Ownership transfer denied" : "所有権の譲渡が拒否されました",
    "Your ownership transfer of {path} was denied by {user}." : "{path}の所有権の譲渡が{user}によって拒否されました。",
    "Ownership transfer failed" : "所有権の譲渡に失敗しました",
    "Your ownership transfer of {path} to {user} failed." : "{path}の{user}への所有権転送に失敗しました。",
    "The ownership transfer of {path} from {user} failed." : "{user} からの {path} の所有権転送に失敗しました。",
    "Ownership transfer done" : "所有権の譲渡が完了しました",
    "Your ownership transfer of {path} to {user} has completed." : "{user} への {path} の所有権転送が完了しました。",
    "The ownership transfer of {path} from {user} has completed." : "{user} からの {path} の所有権転送が完了しました。",
    "in %s" : "%s で",
    "Transferred from %1$s on %2$s" : "%1$sから%2$sに転送",
    "File Management" : "ファイル管理",
    "Home" : "ホーム",
    "Target folder does not exist any more" : "対象フォルダーがもう存在しません",
    "Reload current directory" : "カレントディレクトリの再読み込み",
    "Go to the \"{dir}\" directory" : "\"{dir}\" ディレクトリに移動する",
    "Current directory path" : "現在のディレクトリパス",
    "Your have used your space quota and cannot upload files anymore" : "あなたのクォータ容量を使い果たし、ファイルをアップロードできなくなりました。",
    "You do not have permission to upload or create files here." : "ここにファイルをアップロードまたは作成する権限がありません。",
    "Drag and drop files here to upload" : "ここにファイルをドラッグ＆ドロップしてアップロードする",
    "Favorite" : "お気に入り",
    "Back" : "戻る",
    "Toggle selection for file \"{displayName}\"" : "ファイル \"{displayName}\" の選択を切り替える",
    "Toggle selection for folder \"{displayName}\"" : "フォルダ \"{displayName}\" の選択を切り替える",
    "File is loading" : "ファイル読み込み中",
    "Folder is loading" : "フォルダーを読み込み中",
    "Filename" : "ファイル名",
    "Folder name" : "フォルダー名",
    "This node is unavailable" : "このノードは利用できません",
    "Another entry with the same name already exists." : "同じ名前の別のエントリがすでに存在しています。",
    "Invalid filename." : "無効なファイル名。",
    "Renamed \"{oldName}\" to \"{newName}\"" : "\"{oldName}\" から \"{newName}\" に名前を変更済み",
    "Rename file" : "ファイル名の変更",
    "Folder" : "フォルダー",
    "Unknown file type" : "不明なファイルタイプ",
    "{ext} image" : "{ext}画像",
    "{ext} video" : "{ext}ビデオ",
    "{ext} audio" : "{ext}音声",
    "{ext} text" : "{ext}テキスト",
    "Pending" : "保留中",
    "Unknown date" : "不明な日付",
    "Clear filter" : "フィルターをクリア",
    "Modified" : "更新日時",
    "Search everywhere" : "あらゆる場所を検索",
    "Type" : "タイプ",
    "Active filters" : "有効なフィルター",
    "Remove filter" : "フィルターを削除",
    "Total rows summary" : "総行数のサマリー",
    "Toggle selection for all files and folders" : "すべてのファイルとフォルダの選択を切り替える",
    "Name" : "名前",
    "File type" : "ファイルの種類",
    "Size" : "サイズ",
    "{displayName}: failed on some elements" : "{displayName}: いくつかの要素で失敗しました",
    "{displayName}: done" : "{displayName}: 完了",
    "{displayName}: failed" : "{displayName}: 失敗",
    "Actions" : "アクション",
    "(selected)" : "(選択済み)",
    "List of files and folders." : "ファイルとフォルダの一覧。",
    "You have used your space quota and cannot upload files anymore." : "あなたのクォータ容量を使い果たし、ファイルをアップロードできなくなりました。",
    "Column headers with buttons are sortable." : "ボタン付きの列ヘッダはソート可能です。",
    "This list is not fully rendered for performance reasons. The files will be rendered as you navigate through the list." : "このリストはパフォーマンスの都合上、すべてレンダリングされているわけではありません。リスト内を移動すると、ファイルが次々と表示されていきます。",
    "File not found" : "ファイルが見つかりません",
    "_{count} selected_::_{count} selected_" : ["{count}選択済み"],
    "Search everywhere …" : "あらゆる場所を検索 …",
    "Search here …" : "ここを検索 …",
    "Search scope options" : "検索範囲オプション",
    "Search here" : "ここを検索",
    "{usedQuotaByte} used" : "{usedQuotaByte} 使用されています",
    "{used} of {quota} used" : "{used} / {quota} 使用中",
    "{relative}% used" : "{relative}% 使用されています",
    "Could not refresh storage stats" : "ストレージの状態を更新できませんでした",
    "Your storage is full, files can not be updated or synced anymore!" : "ストレージは一杯です。ファイルの更新と同期はできません！",
    "Storage information" : "ストレージ情報",
    "Storage quota" : "ストレージのクォータ",
    "New folder" : "新しいフォルダー",
    "Create new folder" : "新しいフォルダーを作成",
    "This name is already in use." : "この名前は既に使用されています。",
    "Create" : "作成",
    "Files starting with a dot are hidden by default" : "ドットで始まるファイルはデフォルトで非表示になっています",
    "Failed to start filename sanitization." : "ファイル名のサニタイズを開始できませんでした。",
    "Failed to refresh filename sanitization status." : "ファイル名のサニタイズステータスの更新に失敗しました。",
    "Filename sanitization in progress." : "ファイル名のサニタイズが進行中です。",
    "Currently {processedUsers} of {totalUsers} accounts are already processed." : "現在、{totalUsers}アカウントの{processedUsers}はすでに処理されています。",
    "Preparing …" : "準備中 …",
    "Refresh" : "更新",
    "All files have been santized for Windows filename support." : "全てのファイルはWindowsファイル名をサポートするようにサンタイジングされています。",
    "Some files could not be sanitized, please check your logs." : "一部のファイルをサニタイズできませんでした。ログを確認してください。",
    "Sanitization errors" : "サニタイズエラー",
    "Not sanitized filenames" : "サニタイズされていないファイル名",
    "Windows filename support has been enabled." : "Windowsファイル名のサポートが有効になりました。",
    "While this blocks users from creating new files with unsupported filenames, existing files are not yet renamed and thus still may break sync on Windows." : "これにより、ユーザーはサポートされていないファイル名で新しいファイルを作成できなくなりますが、既存のファイルはまだ名前が変更されていないため、Windowsで同期が中断される可能性があります。",
    "You can trigger a rename of files with invalid filenames, this will be done in the background and may take some time." : "無効なファイル名を持つファイルの名前変更をトリガーできます。これはバックグラウンドで実行され、時間がかかる場合があります。",
    "Please note that this may cause high workload on the sync clients." : "これにより、同期クライアントのワークロードが高くなる可能性があることに注意してください。",
    "Limit" : "制限",
    "This allows to configure how many users should be processed in one background job run." : "これにより、1回のバックグラウンドジョブ実行で処理するユーザー数を構成できます。",
    "Sanitize filenames" : "ファイル名のサニタイズ",
    "(starting)" : "(開始)",
    "Fill template fields" : "テンプレートフィールドへの入力",
    "Submitting fields …" : "フィールドを送信中…",
    "Submit" : "提出する",
    "Choose a file or folder to transfer" : "譲渡するファイルまたはフォルダーを選択してください",
    "Transfer" : "転送",
    "Transfer {path} to {userid}" : "{path} を {userid} に転送する",
    "Invalid path selected" : "無効なパスが選択されました",
    "Unknown error" : "不明なエラー",
    "Ownership transfer request sent" : "所有権転送のリクエストを送信しました",
    "Cannot transfer ownership of a file or folder you do not own" : "所有していないファイルまたはフォルダーの所有権を譲渡することはできません",
    "Transfer ownership of a file or folder" : "ファイルまたはフォルダーの所有権を譲渡する",
    "Choose file or folder to transfer" : "譲渡するファイルまたはフォルダーを選択してください",
    "Change" : "変更",
    "New owner" : "新しい所有者",
    "Keep {old}" : "{old} を保持",
    "Keep without extension" : "延長せずに保持",
    "Use {new}" : "{new}を使用する",
    "Remove extension" : "拡張子を削除",
    "Change file extension" : "ファイル拡張子を変更",
    "Changing the file extension from \"{old}\" to \"{new}\" may render the file unreadable." : "ファイル拡張子を \"{old}\" から \"{new}\" に変更すると、ファイルが読み取れなくなる可能性があります。",
    "Removing the file extension \"{old}\" may render the file unreadable." : "ファイル拡張子 \"{old}\" を削除すると、ファイルが読み取れなくなる可能性があります。",
    "Adding the file extension \"{new}\" may render the file unreadable." : "ファイル拡張子 \"{new}\" を追加すると、ファイルが読み取れなくなる可能性があります。",
    "Do not show this dialog again." : "このダイアログを二度と表示しない。",
    "Select file or folder to link to" : "リンク先のファイルまたはフォルダを選択",
    "Choose {file}" : "{file}を選択",
    "Clipboard is not available" : "クリップボードは利用できません",
    "WebDAV URL copied" : "WebDAV URLをコピーしました",
    "Files settings" : "ファイルの設定",
    "General" : "一般",
    "Default view" : "デフォルト表示",
    "All files" : "すべてのファイル",
    "Personal files" : "個人ファイル",
    "Sort favorites first" : "お気に入りを最初に並べる",
    "Sort folders before files" : "ファイルよりもフォルダを先に並べ替えます",
    "Folder tree" : "フォルダーツリー",
    "Appearance" : "表示",
    "Show hidden files" : "隠しファイルを表示",
    "Show file type column" : "ファイルの種類のカラムを表示する",
    "Show file extensions" : "ファイルの拡張子を表示",
    "Crop image previews" : "プレビュー画像を切り抜く",
    "Additional settings" : "追加設定",
    "WebDAV" : "WebDAV",
    "WebDAV URL" : "WebDAV URL",
    "Copy" : "コピー",
    "How to access files using WebDAV" : "WebDAVを使用してファイルにアクセスする方法",
    "Two-Factor Authentication is enabled for your account, and therefore you need to use an app password to connect an external WebDAV client." : "2要素認証がアカウントに有効化されています。そのため、外部WebDAVクライアントを接続するにはアプリパスワードを使用する必要があります。",
    "Warnings" : "警告",
    "Warn before changing a file extension" : "ファイル拡張子を変更する前に警告する",
    "Warn before deleting files" : "ファイルを削除する前に警告する",
    "Keyboard shortcuts" : "キーボードショートカット",
    "File actions" : "ファイルアクション",
    "Rename" : "名前の変更",
    "Delete" : "削除",
    "Add or remove favorite" : "お気に入りを追加または削除",
    "Manage tags" : "タグを管理",
    "Selection" : "選択",
    "Select all files" : "全てのファイルを選択",
    "Deselect all" : "選択を全解除",
    "Select or deselect" : "選択または解除",
    "Select a range" : "範囲を選択",
    "Navigation" : "ナビゲーション",
    "Go to parent folder" : "親フォルダーへ移動",
    "Go to file above" : "上のファイルに移動",
    "Go to file below" : "下のファイルに移動",
    "Go left in grid" : "グリッド内を左に移動",
    "Go right in grid" : "グリッド内を右に移動",
    "View" : "表示",
    "Toggle grid view" : "グリッド表示の切り替え",
    "Open file sidebar" : "ファイルサイドバーを開く",
    "Show those shortcuts" : "これらのショートカットを表示する",
    "Share" : "共有",
    "Shared by link" : "URLリンクで共有中",
    "Shared" : "共有中",
    "Switch to list view" : "リスト表示へ切り替え",
    "Switch to grid view" : "グリッド表示へ切り替え",
    "The file could not be found" : "ファイルが見つかりませんでした",
    "Upload was cancelled by user" : "アップロードはユーザーによってキャンセルされました",
    "Not enough free space" : "十分な空き容量がありません",
    "Operation is blocked by access control" : "アクセス制御により操作がブロックされました",
    "Error during upload: {message}" : "アップロード中にエラーが発生しました: {message}",
    "Error during upload, status code {status}" : "アップロード中のエラー、ステータスコード {status}",
    "Unknown error during upload" : "不明なエラーがアップロード中に発生しました",
    "Loading current folder" : "現在のフォルダの読み込み中",
    "Retry" : "リトライ",
    "No files in here" : "ファイルがありません",
    "Upload some content or sync with your devices!" : "何かコンテンツをアップロードするか、デバイスからファイルを同期してください。",
    "Go back" : "戻る",
    "Views" : "表示",
    "You" : "自分",
    "Shared multiple times with different people" : "異なる人と複数回共有",
    "Unable to change the favorite state of the file" : "ファイルのお気に入りの状態を変更できません",
    "Error while loading the file data" : "ファイルデータの読み込み中にエラーが発生しました",
    "Owner" : "作成者",
    "Remove from favorites" : "お気に入りから削除",
    "Add to favorites" : "お気に入りに追加",
    "Tags" : "タグ",
    "Your files" : "あなたのファイル",
    "Open in files" : "ファイルで開く",
    "File cannot be accessed" : "ファイルにアクセスできません",
    "The file could not be found or you do not have permissions to view it. Ask the sender to share it." : "ファイルが見つからないか、あなたがそれを表示する権限を持っていない可能性があります。送信者に共有するように依頼してください。",
    "No search results for “{query}”" : "\"{query}\"に関する検索結果はありません",
    "Search for files" : "ファイルを検索",
    "Allow to restrict filenames to ensure files can be synced with all clients. By default all filenames valid on POSIX (e.g. Linux or macOS) are allowed." : "ファイルをすべてのクライアントと同期できるようにするために、ファイル名を制限することを許可します。デフォルトではPOSIX（LinuxやmacOSなど）で有効なすべてのファイル名が許可されています。",
    "After enabling the Windows compatible filenames, existing files cannot be modified anymore but can be renamed to valid new names by their owner." : "Windows 互換のファイル名を有効にすると、既存のファイルは変更できなくなりますが、所有者が有効な新しいファイル名に変更できるようになります。",
    "Failed to toggle Windows filename support" : "Windowsファイル名サポートの切り替えに失敗しました",
    "Files compatibility" : "ファイルの互換性",
    "Enforce Windows compatibility" : "Windowsとの互換性を強制",
    "This will block filenames not valid on Windows systems, like using reserved names or special characters. But this will not enforce compatibility of case sensitivity." : "予約名や特殊文字のような、Windowsシステムにおいて有効でないファイル名をブロックします。これは大文字、小文字の互換性を強制するものではありません。",
    "Blank" : "ブランク",
    "Unable to create new file from template" : "テンプレートから新しいファイルを作成できません",
    "Pick a template for {name}" : "{name} のテンプレートを選択してください",
    "Create a new file with the selected template" : "選択したテンプレートを使用して新しいファイルを作成します",
    "Creating file" : "ファイル作成",
    "Save as {displayName}" : "{displayName}として保存",
    "Save as …" : "保存…",
    "Converting files …" : "ファイルの変換…",
    "Failed to convert files: {message}" : "ファイルの変換に失敗しました: {message}",
    "All files failed to be converted" : "すべてのファイルの変換に失敗しました",
    "One file could not be converted: {message}" : "1つのファイルが変換できませんでした: {message}",
    "_One file could not be converted_::_%n files could not be converted_" : ["%n個のファイルが変換できませんでした"],
    "_One file successfully converted_::_%n files successfully converted_" : ["%n個のファイルの変換に成功しました"],
    "Files successfully converted" : "ファイルは正常に変換されました",
    "Failed to convert files" : "ファイルの変換に失敗しました",
    "Converting file …" : "ファイルの変換…",
    "File successfully converted" : "ファイルは正常に変換されました",
    "Failed to convert file: {message}" : "ファイルの変換に失敗しました: {message}",
    "Failed to convert file" : "ファイルの変換に失敗しました",
    "Leave this share" : "この共有から抜ける",
    "Leave these shares" : "これらの共有から抜ける",
    "Disconnect storage" : "ストレージを切断する",
    "Disconnect storages" : "ストレージを切断する",
    "Delete permanently" : "完全に削除する",
    "Delete and unshare" : "削除して共有を解除",
    "Delete file" : "ファイルを削除",
    "Delete files" : "ファイルの削除",
    "Delete folder" : "フォルダーを削除",
    "Delete folders" : "フォルダを削除",
    "_You are about to permanently delete {count} item_::_You are about to permanently delete {count} items_" : ["{count}アイテムを完全に削除しようとしています"],
    "_You are about to delete {count} item_::_You are about to delete {count} items_" : ["あなたは {count} 個のアイテムを削除しようとしています"],
    "Confirm deletion" : "削除の確認",
    "Cancel" : "キャンセル",
    "Download" : "ダウンロード",
    "The requested file is not available." : "要求されたファイルは使用できません。",
    "The requested files are not available." : "要求されたファイルは使用できません。",
    "Moving \"{source}\" to \"{destination}\" …" : "\"{source}\" を \"{destination}\"に移動",
    "Copying \"{source}\" to \"{destination}\" …" : "\"{source}\" を \"{destination}\"にコピー",
    "Destination is not a folder" : "宛先がフォルダではありません",
    "This file/folder is already in that directory" : "このファイル/フォルダはすでにそのディレクトリにあります",
    "You cannot move a file/folder onto itself or into a subfolder of itself" : "ファイル/フォルダをそれ自身の上に移動したり、それ自身のサブフォルダに移動したりすることはできません。",
    "(copy)" : "(copy)",
    "(copy %n)" : "(copy %n)",
    "A file or folder with that name already exists in this folder" : "その名前のファイルまたはフォルダが、このフォルダに既に存在します",
    "The files are locked" : "ファイルはロックされています",
    "The file does not exist anymore" : "ファイルはもう存在しません",
    "Choose destination" : "移動先を選択",
    "Copy to {target}" : "{target} にコピー",
    "Move to {target}" : "{target} に移動",
    "Move" : "移動",
    "Move or copy operation failed" : "移動またはコピー操作は失敗しました",
    "Move or copy" : "移動またはコピー",
    "Open folder {displayName}" : "フォルダ {displayName} を開く",
    "Open in Files" : "ファイルアプリで開く",
    "Open locally" : "ローカルで開く",
    "Failed to redirect to client" : "クライアントへリダイレクトできませんでした",
    "Open file locally" : "ローカルでファイルを開く",
    "The file should now open on your device. If it doesn't, please check that you have the desktop app installed." : "ファイルがデバイス上で開くはずです。開かない場合は、デスクトップアプリがインストールされているかご確認ください。",
    "Retry and close" : "再試行して閉じる",
    "Open online" : "オンラインで開く",
    "Details" : "詳細",
    "View in folder" : "フォルダー内で表示",
    "Today" : "今日",
    "Last 7 days" : "7日以内",
    "Last 30 days" : "30日以内",
    "This year ({year})" : "今年 ({year})",
    "Last year ({year})" : "去年 ({year})",
    "Documents" : "ドキュメント",
    "Spreadsheets" : "スプレッドシート",
    "Presentations" : "プレゼンテーション",
    "PDFs" : "PDF",
    "Folders" : "フォルダー",
    "Audio" : "オーディオ",
    "Images" : "画像",
    "Videos" : "動画",
    "Created new folder \"{name}\"" : "新規フォルダ \"{name}\" を作成しました",
    "Unable to initialize the templates directory" : "テンプレートディレクトリを初期化できませんでした",
    "Create templates folder" : "テンプレートフォルダーの作成",
    "Templates" : "テンプレート",
    "New template folder" : "新しいテンプレートフォルダ",
    "In folder" : "フォルダ内",
    "Search in all files" : "すべてのファイルを検索",
    "Search in folder: {folder}" : "フォルダ内を検索: {folder}",
    "One of the dropped files could not be processed" : "ドロップされたファイルの1つが処理できませんでした",
    "Your browser does not support the Filesystem API. Directories will not be uploaded" : "お使いのブラウザはファイルシステムAPIをサポートしていません。ディレクトリはアップロードされません",
    "No files to upload" : "アップロードするファイルがありません",
    "Unable to create the directory {directory}" : "ディレクトリ {directory} を作成できません",
    "Some files could not be uploaded" : "いくつかのファイルがアップロードできませんでした",
    "Files uploaded successfully" : "ファイルが正常にアップロードされました",
    "No files to process" : "処理するファイルがありません",
    "Some files could not be copied" : "いくつかのファイルがコピーできません",
    "Some files could not be moved" : "いくつかのファイルが移動できません",
    "Files copied successfully" : "ファイルが正常にコピーされました",
    "Files moved successfully" : "ファイルの移動に成功しました",
    "Conflicts resolution skipped" : "コンフリクトの解決はスキップされました",
    "Upload cancelled" : "アップロードはキャンセルされました",
    "Could not rename \"{oldName}\", it does not exist any more" : "\"{oldName}\" の名前を変更できませんでした、それは既に存在しません。",
    "The name \"{newName}\" is already used in the folder \"{dir}\". Please choose a different name." : "\"{newName}\" という名前は \"{dir}\" フォルダですでに使用されています。別の名前を選択してください。",
    "Could not rename \"{oldName}\"" : "\"{oldName}\" の名前を変更できませんでした。",
    "This operation is forbidden" : "この操作は禁止されています",
    "This folder is unavailable, please try again later or contact the administration" : "このフォルダーは使用できません。後で再試行するか管理者に問い合わせてください",
    "Storage is temporarily not available" : "ストレージは一時的に利用できません",
    "Unexpected error: {error}" : "予期せぬエラー: {error}",
    "_%n file_::_%n files_" : ["%n 個のファイル"],
    "_%n folder_::_%n folders_" : ["%n 個のフォルダー"],
    "_%n hidden_::_%n hidden_" : ["%n 非公開"],
    "Filename must not be empty." : "ファイル名は空白にできません。",
    "\"{char}\" is not allowed inside a filename." : "\"{char}\"はファイル名には使用できません。",
    "\"{segment}\" is a reserved name and not allowed for filenames." : "\"{segment}\"は予約名であり、ファイル名には使用できません。",
    "\"{extension}\" is not an allowed filetype." : "\"{extension}\" は許可されたファイルタイプではありません。",
    "Filenames must not end with \"{extension}\"." : "ファイル名は \"{extension}\"で終了できません。",
    "List of favorite files and folders." : "お気に入りのファイルやフォルダーの一覧",
    "No favorites yet" : "まだお気に入りはありません",
    "Files and folders you mark as favorite will show up here" : "お気に入りに登録されたファイルやフォルダーは、ここに表示されます。",
    "List of your files and folders." : "ファイルやフォルダーの一覧",
    "List of your files and folders that are not shared." : "共有されていないファイルやフォルダの一覧。",
    "No personal files found" : "個人ファイルは見つかりませんでした",
    "Files that are not shared will show up here." : "共有されていないファイルは、ここに表示されます。",
    "Recent" : "最新",
    "List of recently modified files and folders." : "最近変更されたファイルとフォルダーのリスト",
    "No recently modified files" : "最近更新されたファイルはありません",
    "Files and folders you recently modified will show up here." : "最近変更したファイルやフォルダーがここに表示されます。",
    "Search" : "検索",
    "Search results within your files." : "ファイル内の検索結果",
    "No entries found in this folder" : "このフォルダーにはエントリーがありません",
    "Select all" : "すべて選択",
    "Upload too large" : "アップロードには大きすぎます。",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "アップロードしようとしているファイルは、このサーバーのファイルアップロード時の最大サイズを超えています。",
    "%1$s (renamed)" : "%1$s (リネーム済み)",
    "renamed file" : "リネーム済みファイル",
    "Upload (max. %s)" : "アップロード ( 最大 %s )",
    "After enabling the windows compatible filenames, existing files cannot be modified anymore but can be renamed to valid new names by their owner." : "Windows 互換のファイル名を有効にすると、既存のファイルは変更できなくなりますが、所有者が有効な新しいファイル名に変更できるようになります。",
    "It is also possible to migrate files automatically after enabling this setting, please refer to the documentation about the occ command." : "この設定を有効にした後、自動的にファイルを移行することも可能です。occコマンドに関するドキュメントを参照してください。",
    "\"{displayName}\" failed on some elements" : "いくつかの要素で \"{displayName}\" が失敗しました。",
    "\"{displayName}\" batch action executed successfully" : "\"{displayName}\" バッチアクションが正常に実行されました。",
    "\"{displayName}\" action failed" : "\"{displayName}\" アクションは失敗しました",
    "Submitting fields …" : "フィールドを送信中…",
    "\"{displayName}\" action executed successfully" : "\"{displayName}\" アクションは正常に実行されました",
    "Filter file names …" : "ファイルネームフィルター…",
    "WebDAV URL copied to clipboard" : "WebDAVのURLがクリップボードにコピーされました",
    "Enable the grid view" : "グリッド表示を有効にする",
    "Enable folder tree" : "フォルダーツリーを有効にする",
    "Copy to clipboard" : "クリップボードにコピー",
    "Use this address to access your Files via WebDAV" : "このアドレスを使用すれば、WebDAV経由でファイルにアクセスできます",
    "If you have enabled 2FA, you must create and use a new app password by clicking here." : "2FAを有効にしている場合は、ここをクリックして新しいアプリのパスワードを作成し、使用する必要があります。",
    "Prevent warning dialogs from open or reenable them." : "警告ダイアログが開かないようにするか、再度有効にする。",
    "Show a warning dialog when changing a file extension." : "ファイルの拡張子を変更する際に、警告ダイアログを表示する。",
    "Speed up your Files experience with these quick shortcuts." : "これらのショートカットでファイルの取り扱いを高速化します",
    "Open the actions menu for a file" : "ファイルのアクションメニューを開く",
    "Rename a file" : "ファイル名を変更",
    "Delete a file" : "ファイルを削除",
    "Favorite or remove a file from favorites" : "ファイルをお気に入りから追加または削除",
    "Manage tags for a file" : "ファイルのタグを管理する",
    "Deselect all files" : "全てのファイルの選択を解除",
    "Select or deselect a file" : "ファイルを選択または選択を解除",
    "Select a range of files" : "範囲内のファイルを選択",
    "Navigate to the parent folder" : "親フォルダーに移動",
    "Navigate to the file above" : "上のファイルに移動",
    "Navigate to the file below" : "下のファイルに移動",
    "Navigate to the file on the left (in grid mode)" : "左のファイルに移動（グリッドモード）",
    "Navigate to the file on the right (in grid mode)" : "右のファイルに移動（グリッドモード）",
    "Toggle the grid view" : "グリッドビューを切り替え",
    "Open the sidebar for a file" : "ファイルのサイドバーを開く",
    "Save as …" : "保存…",
    "Converting files …" : "ファイルの変換…",
    "Converting file …" : "ファイルの変換…",
    "Deletion cancelled" : "削除はキャンセルされました",
    "Edit locally" : "ローカルで編集",
    "Moving \"{source}\" to \"{destination}\" …" : "\"{source}\" を \"{destination}\"に移動",
    "Copying \"{source}\" to \"{destination}\" …" : "\"{source}\" を \"{destination}\"にコピー",
    "Move cancelled" : "移動はキャンセルされました",
    "Cancelled move or copy of \"{filename}\"." : "\"{filename}\"の移動またはコピーをキャンセルしました。",
    "Cancelled move or copy operation" : "キャンセルされた移動またはコピー操作",
    "Open details" : "詳細を開く",
    "Photos and images" : "写真と画像",
    "New folder creation cancelled" : "新しいフォルダーの作成がキャンセルされました",
    "This directory is unavailable, please check the logs or contact the administrator" : "このディレクトリは利用できません。ログを確認するか管理者に問い合わせてください。",
    "All folders" : "全てのフォルダー",
    "Search everywhere …" : "あらゆる場所を検索 …",
    "Search here …" : "ここを検索 …",
    "Preparing …" : "準備中 …"
},
"nplurals=1; plural=0;");
